<?php
/**
 * JM_Web_Development\Nuovo\Social_Media\Component class
 *
 * @package nuovo
 */

namespace JM_Web_Development\Nuovo\Social_Media;

use JM_Web_Development\Nuovo\Component_Interface;
use JM_Web_Development\Nuovo\Templating_Component_Interface;
use function add_action;
use function add_filter;
use function register_sidebar;
use function esc_html__;
use function is_active_sidebar;
use function dynamic_sidebar;

/**
 * Class for managing sidebars.
 *
 * Exposes template tags:
 * * `nuovo()->is_primary_sidebar_active()`
 * * `nuovo()->display_primary_sidebar()`
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/
 */
class Component implements Templating_Component_Interface, Component_Interface {

	/**
	 * Gets the unique identifier for the theme component.
	 *
	 * @return string Component slug.
	 */
	public function get_slug() : string {
		return 'social-media';
	}

	/**
	 * Adds the action and filter hooks to integrate with WordPress.
	 */
	public function initialize() {

	}

	/**
	 * Gets template tags to expose as methods on the Template_Tags class instance, accessible through `nuovo()`.
	 *
	 * @return array Associative array of $method_name => $callback_info pairs. Each $callback_info must either be
	 *               a callable or an array with key 'callable'. This approach is used to reserve the possibility of
	 *               adding support for further arguments in the future.
	 */
	public function template_tags() : array {
		return [
			'social_media_links' => [ $this, 'social_media_links' ],
		];
	}

	/**
	 * Displays social media links for the site.
	 *
	 * @since 2.0.0
	 *
	 * @return string      The HTML for the social media section.
	 */
	public function social_media_links() {
		$html = '<div class="social-links">';
		if ( esc_attr( get_theme_mod( 'nuovo-facebook' ) ) ) {
			$html .= '<a href="' . esc_url( get_theme_mod( 'nuovo-facebook' ) ) . '" target="_blank" class="social-icon facebook"><span class="fab fa-facebook-f"><span class="screen-reader-text">' . esc_html__( 'Facebook Profile', 'nuovo' ) . '</span></span></a>';
		}
		if ( esc_attr( get_theme_mod( 'nuovo-twitter' ) ) ) {
			$html .= '<a href="' . esc_url( get_theme_mod( 'nuovo-twitter' ) ) . '" target="_blank" class="social-icon twitter"><span class="fab fa-twitter"><span class="screen-reader-text">' . esc_html__( 'Twitter Profile', 'nuovo' ) . '</span></span></a>';
		}
		if ( esc_attr( get_theme_mod( 'nuovo-youtube' ) ) ) {
			$html .= '<a href="' . esc_url( get_theme_mod( 'nuovo-youtube' ) ) . '" target="_blank" class="social-icon youtube"><span class="fab fa-youtube"><span class="screen-reader-text">' . esc_html__( 'YouTube Channel', 'nuovo' ) . '</span></span></a>';
		}
		if ( esc_attr( get_theme_mod( 'nuovo-tumblr' ) ) ) {
			$html .= '<a href="' . esc_url( get_theme_mod( 'nuovo-tumblr' ) ) . '" target="_blank" class="social-icon tumblr"><span class="fab fa-tumblr"><span class="screen-reader-text">' . esc_html__( 'Tumblr Blog', 'nuovo' ) . '</span></span></a>';
		}
		if ( esc_attr( get_theme_mod( 'nuovo-instagram' ) ) ) {
			$html .= '<a href="' . esc_url( get_theme_mod( 'nuovo-instagram' ) ) . '" target="_blank" class="social-icon instagram"><span class="fab fa-instagram"><span class="screen-reader-text">' . esc_html__( 'Facebook Profile', 'nuovo' ) . '</span></span></a>';
		}
		if ( esc_attr( get_theme_mod( 'nuovo-rss-feed' ) ) ) {
			$html .= '<a href="' . esc_url( get_theme_mod( 'nuovo-rss-feed' ) ) . '" target="_blank class="social-icon rss-feed""><span class="fas fa-rss"><span class="screen-reader-text">' . esc_html__( 'RSS Feed', 'nuovo' ) . '</span></span></a>';
		} else {
			$html .= '<a href="' . get_feed_link( 'rss' ) . '" target="_blank" class="social-icon rss-feed"><span class="fas fa-rss"><span class="screen-reader-text">' . esc_html__( 'RSS Feed', 'nuovo' ) . '</span></span></a>';
		}
		$html .= '</div>';
		return $html;
	}
}
